# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from privy_client import PrivyAPI, AsyncPrivyAPI
from privy_client.types import KeyQuorum

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestKeyQuorums:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: PrivyAPI) -> None:
        key_quorum = client.key_quorums.create(
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----",
                '-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAErzZtQr/bMIh3Y8f9ZqseB9i/AfjQ\nhu+agbNqXcJy/TfoNqvc/Y3Mh7gIZ8ZLXQEykycx4mYSpqrxp1lBKqsZDQ==\n-----END PUBLIC KEY-----",',
            ],
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: PrivyAPI) -> None:
        key_quorum = client.key_quorums.create(
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----",
                '-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAErzZtQr/bMIh3Y8f9ZqseB9i/AfjQ\nhu+agbNqXcJy/TfoNqvc/Y3Mh7gIZ8ZLXQEykycx4mYSpqrxp1lBKqsZDQ==\n-----END PUBLIC KEY-----",',
            ],
            authorization_threshold=1,
            display_name="Prod key quorum",
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: PrivyAPI) -> None:
        response = client.key_quorums.with_raw_response.create(
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----",
                '-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAErzZtQr/bMIh3Y8f9ZqseB9i/AfjQ\nhu+agbNqXcJy/TfoNqvc/Y3Mh7gIZ8ZLXQEykycx4mYSpqrxp1lBKqsZDQ==\n-----END PUBLIC KEY-----",',
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key_quorum = response.parse()
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: PrivyAPI) -> None:
        with client.key_quorums.with_streaming_response.create(
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----",
                '-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAErzZtQr/bMIh3Y8f9ZqseB9i/AfjQ\nhu+agbNqXcJy/TfoNqvc/Y3Mh7gIZ8ZLXQEykycx4mYSpqrxp1lBKqsZDQ==\n-----END PUBLIC KEY-----",',
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key_quorum = response.parse()
            assert_matches_type(KeyQuorum, key_quorum, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: PrivyAPI) -> None:
        key_quorum = client.key_quorums.update(
            key_quorum_id="key_quorum_id",
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----"
            ],
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: PrivyAPI) -> None:
        key_quorum = client.key_quorums.update(
            key_quorum_id="key_quorum_id",
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----"
            ],
            authorization_threshold=1,
            display_name="Prod key quorum",
            privy_authorization_signature="privy-authorization-signature",
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: PrivyAPI) -> None:
        response = client.key_quorums.with_raw_response.update(
            key_quorum_id="key_quorum_id",
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----"
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key_quorum = response.parse()
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: PrivyAPI) -> None:
        with client.key_quorums.with_streaming_response.update(
            key_quorum_id="key_quorum_id",
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----"
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key_quorum = response.parse()
            assert_matches_type(KeyQuorum, key_quorum, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_update(self, client: PrivyAPI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `key_quorum_id` but received ''"):
            client.key_quorums.with_raw_response.update(
                key_quorum_id="",
                public_keys=[
                    "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----"
                ],
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_delete(self, client: PrivyAPI) -> None:
        key_quorum = client.key_quorums.delete(
            key_quorum_id="key_quorum_id",
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_delete_with_all_params(self, client: PrivyAPI) -> None:
        key_quorum = client.key_quorums.delete(
            key_quorum_id="key_quorum_id",
            privy_authorization_signature="privy-authorization-signature",
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete(self, client: PrivyAPI) -> None:
        response = client.key_quorums.with_raw_response.delete(
            key_quorum_id="key_quorum_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key_quorum = response.parse()
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete(self, client: PrivyAPI) -> None:
        with client.key_quorums.with_streaming_response.delete(
            key_quorum_id="key_quorum_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key_quorum = response.parse()
            assert_matches_type(KeyQuorum, key_quorum, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_delete(self, client: PrivyAPI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `key_quorum_id` but received ''"):
            client.key_quorums.with_raw_response.delete(
                key_quorum_id="",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_get(self, client: PrivyAPI) -> None:
        key_quorum = client.key_quorums.get(
            "key_quorum_id",
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get(self, client: PrivyAPI) -> None:
        response = client.key_quorums.with_raw_response.get(
            "key_quorum_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key_quorum = response.parse()
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get(self, client: PrivyAPI) -> None:
        with client.key_quorums.with_streaming_response.get(
            "key_quorum_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key_quorum = response.parse()
            assert_matches_type(KeyQuorum, key_quorum, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_get(self, client: PrivyAPI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `key_quorum_id` but received ''"):
            client.key_quorums.with_raw_response.get(
                "",
            )


class TestAsyncKeyQuorums:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncPrivyAPI) -> None:
        key_quorum = await async_client.key_quorums.create(
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----",
                '-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAErzZtQr/bMIh3Y8f9ZqseB9i/AfjQ\nhu+agbNqXcJy/TfoNqvc/Y3Mh7gIZ8ZLXQEykycx4mYSpqrxp1lBKqsZDQ==\n-----END PUBLIC KEY-----",',
            ],
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncPrivyAPI) -> None:
        key_quorum = await async_client.key_quorums.create(
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----",
                '-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAErzZtQr/bMIh3Y8f9ZqseB9i/AfjQ\nhu+agbNqXcJy/TfoNqvc/Y3Mh7gIZ8ZLXQEykycx4mYSpqrxp1lBKqsZDQ==\n-----END PUBLIC KEY-----",',
            ],
            authorization_threshold=1,
            display_name="Prod key quorum",
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncPrivyAPI) -> None:
        response = await async_client.key_quorums.with_raw_response.create(
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----",
                '-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAErzZtQr/bMIh3Y8f9ZqseB9i/AfjQ\nhu+agbNqXcJy/TfoNqvc/Y3Mh7gIZ8ZLXQEykycx4mYSpqrxp1lBKqsZDQ==\n-----END PUBLIC KEY-----",',
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key_quorum = await response.parse()
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncPrivyAPI) -> None:
        async with async_client.key_quorums.with_streaming_response.create(
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----",
                '-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAErzZtQr/bMIh3Y8f9ZqseB9i/AfjQ\nhu+agbNqXcJy/TfoNqvc/Y3Mh7gIZ8ZLXQEykycx4mYSpqrxp1lBKqsZDQ==\n-----END PUBLIC KEY-----",',
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key_quorum = await response.parse()
            assert_matches_type(KeyQuorum, key_quorum, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncPrivyAPI) -> None:
        key_quorum = await async_client.key_quorums.update(
            key_quorum_id="key_quorum_id",
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----"
            ],
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncPrivyAPI) -> None:
        key_quorum = await async_client.key_quorums.update(
            key_quorum_id="key_quorum_id",
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----"
            ],
            authorization_threshold=1,
            display_name="Prod key quorum",
            privy_authorization_signature="privy-authorization-signature",
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncPrivyAPI) -> None:
        response = await async_client.key_quorums.with_raw_response.update(
            key_quorum_id="key_quorum_id",
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----"
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key_quorum = await response.parse()
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncPrivyAPI) -> None:
        async with async_client.key_quorums.with_streaming_response.update(
            key_quorum_id="key_quorum_id",
            public_keys=[
                "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----"
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key_quorum = await response.parse()
            assert_matches_type(KeyQuorum, key_quorum, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_update(self, async_client: AsyncPrivyAPI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `key_quorum_id` but received ''"):
            await async_client.key_quorums.with_raw_response.update(
                key_quorum_id="",
                public_keys=[
                    "-----BEGIN PUBLIC KEY-----\nMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEx4aoeD72yykviK+f/ckqE2CItVIG\n1rCnvC3/XZ1HgpOcMEMialRmTrqIK4oZlYd1RfxU3za/C9yjhboIuoPD3g==\n-----END PUBLIC KEY-----"
                ],
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete(self, async_client: AsyncPrivyAPI) -> None:
        key_quorum = await async_client.key_quorums.delete(
            key_quorum_id="key_quorum_id",
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete_with_all_params(self, async_client: AsyncPrivyAPI) -> None:
        key_quorum = await async_client.key_quorums.delete(
            key_quorum_id="key_quorum_id",
            privy_authorization_signature="privy-authorization-signature",
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncPrivyAPI) -> None:
        response = await async_client.key_quorums.with_raw_response.delete(
            key_quorum_id="key_quorum_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key_quorum = await response.parse()
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncPrivyAPI) -> None:
        async with async_client.key_quorums.with_streaming_response.delete(
            key_quorum_id="key_quorum_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key_quorum = await response.parse()
            assert_matches_type(KeyQuorum, key_quorum, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncPrivyAPI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `key_quorum_id` but received ''"):
            await async_client.key_quorums.with_raw_response.delete(
                key_quorum_id="",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_get(self, async_client: AsyncPrivyAPI) -> None:
        key_quorum = await async_client.key_quorums.get(
            "key_quorum_id",
        )
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get(self, async_client: AsyncPrivyAPI) -> None:
        response = await async_client.key_quorums.with_raw_response.get(
            "key_quorum_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key_quorum = await response.parse()
        assert_matches_type(KeyQuorum, key_quorum, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get(self, async_client: AsyncPrivyAPI) -> None:
        async with async_client.key_quorums.with_streaming_response.get(
            "key_quorum_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key_quorum = await response.parse()
            assert_matches_type(KeyQuorum, key_quorum, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_get(self, async_client: AsyncPrivyAPI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `key_quorum_id` but received ''"):
            await async_client.key_quorums.with_raw_response.get(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .kyc import (
    KYCResource,
    AsyncKYCResource,
    KYCResourceWithRawResponse,
    AsyncKYCResourceWithRawResponse,
    KYCResourceWithStreamingResponse,
    AsyncKYCResourceWithStreamingResponse,
)
from .fiat import (
    FiatResource,
    AsyncFiatResource,
    FiatResourceWithRawResponse,
    AsyncFiatResourceWithRawResponse,
    FiatResourceWithStreamingResponse,
    AsyncFiatResourceWithStreamingResponse,
)
from .onramp import (
    OnrampResource,
    AsyncOnrampResource,
    OnrampResourceWithRawResponse,
    AsyncOnrampResourceWithRawResponse,
    OnrampResourceWithStreamingResponse,
    AsyncOnrampResourceWithStreamingResponse,
)
from .offramp import (
    OfframpResource,
    AsyncOfframpResource,
    OfframpResourceWithRawResponse,
    AsyncOfframpResourceWithRawResponse,
    OfframpResourceWithStreamingResponse,
    AsyncOfframpResourceWithStreamingResponse,
)
from .accounts import (
    AccountsResource,
    AsyncAccountsResource,
    AccountsResourceWithRawResponse,
    AsyncAccountsResourceWithRawResponse,
    AccountsResourceWithStreamingResponse,
    AsyncAccountsResourceWithStreamingResponse,
)

__all__ = [
    "AccountsResource",
    "AsyncAccountsResource",
    "AccountsResourceWithRawResponse",
    "AsyncAccountsResourceWithRawResponse",
    "AccountsResourceWithStreamingResponse",
    "AsyncAccountsResourceWithStreamingResponse",
    "KYCResource",
    "AsyncKYCResource",
    "KYCResourceWithRawResponse",
    "AsyncKYCResourceWithRawResponse",
    "KYCResourceWithStreamingResponse",
    "AsyncKYCResourceWithStreamingResponse",
    "OnrampResource",
    "AsyncOnrampResource",
    "OnrampResourceWithRawResponse",
    "AsyncOnrampResourceWithRawResponse",
    "OnrampResourceWithStreamingResponse",
    "AsyncOnrampResourceWithStreamingResponse",
    "OfframpResource",
    "AsyncOfframpResource",
    "OfframpResourceWithRawResponse",
    "AsyncOfframpResourceWithRawResponse",
    "OfframpResourceWithStreamingResponse",
    "AsyncOfframpResourceWithStreamingResponse",
    "FiatResource",
    "AsyncFiatResource",
    "FiatResourceWithRawResponse",
    "AsyncFiatResourceWithRawResponse",
    "FiatResourceWithStreamingResponse",
    "AsyncFiatResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, overload

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import required_args, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.fiat import kyc_get_params, kyc_create_params, kyc_update_params
from ..._base_client import make_request_options
from ...types.fiat.kyc_get_response import KYCGetResponse
from ...types.fiat.kyc_create_response import KYCCreateResponse
from ...types.fiat.kyc_update_response import KYCUpdateResponse

__all__ = ["KYCResource", "AsyncKYCResource"]


class KYCResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> KYCResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/privy-io/python-sdk#accessing-raw-response-data-eg-headers
        """
        return KYCResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> KYCResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/privy-io/python-sdk#with_streaming_response
        """
        return KYCResourceWithStreamingResponse(self)

    @overload
    def create(
        self,
        user_id: str,
        *,
        data: kyc_create_params.Variant0Data,
        provider: Literal["bridge"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCCreateResponse:
        """
        Initiates KYC verification process for a user with the configured provider

        Args:
          user_id: The ID of the user to initiate KYC for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        user_id: str,
        *,
        data: kyc_create_params.Variant1Data,
        provider: Literal["bridge-sandbox"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCCreateResponse:
        """
        Initiates KYC verification process for a user with the configured provider

        Args:
          user_id: The ID of the user to initiate KYC for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["data", "provider"])
    def create(
        self,
        user_id: str,
        *,
        data: kyc_create_params.Variant0Data,
        provider: Literal["bridge"] | Literal["bridge-sandbox"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCCreateResponse:
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return self._post(
            f"/v1/users/{user_id}/fiat/kyc",
            body=maybe_transform(
                {
                    "data": data,
                    "provider": provider,
                },
                kyc_create_params.KYCCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KYCCreateResponse,
        )

    @overload
    def update(
        self,
        user_id: str,
        *,
        data: kyc_update_params.Variant0Data,
        provider: Literal["bridge"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCUpdateResponse:
        """
        Update the KYC verification status for a user from the configured provider

        Args:
          user_id: The ID of the user to update KYC status for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        user_id: str,
        *,
        data: kyc_update_params.Variant1Data,
        provider: Literal["bridge-sandbox"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCUpdateResponse:
        """
        Update the KYC verification status for a user from the configured provider

        Args:
          user_id: The ID of the user to update KYC status for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["data", "provider"])
    def update(
        self,
        user_id: str,
        *,
        data: kyc_update_params.Variant0Data,
        provider: Literal["bridge"] | Literal["bridge-sandbox"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCUpdateResponse:
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return self._patch(
            f"/v1/users/{user_id}/fiat/kyc",
            body=maybe_transform(
                {
                    "data": data,
                    "provider": provider,
                },
                kyc_update_params.KYCUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KYCUpdateResponse,
        )

    def get(
        self,
        user_id: str,
        *,
        provider: Literal["bridge", "bridge-sandbox"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCGetResponse:
        """
        Get the current KYC verification status for a user from the configured provider

        Args:
          user_id: The ID of the user to get KYC status for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return self._get(
            f"/v1/users/{user_id}/fiat/kyc",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"provider": provider}, kyc_get_params.KYCGetParams),
            ),
            cast_to=KYCGetResponse,
        )


class AsyncKYCResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncKYCResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/privy-io/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncKYCResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncKYCResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/privy-io/python-sdk#with_streaming_response
        """
        return AsyncKYCResourceWithStreamingResponse(self)

    @overload
    async def create(
        self,
        user_id: str,
        *,
        data: kyc_create_params.Variant0Data,
        provider: Literal["bridge"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCCreateResponse:
        """
        Initiates KYC verification process for a user with the configured provider

        Args:
          user_id: The ID of the user to initiate KYC for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        user_id: str,
        *,
        data: kyc_create_params.Variant1Data,
        provider: Literal["bridge-sandbox"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCCreateResponse:
        """
        Initiates KYC verification process for a user with the configured provider

        Args:
          user_id: The ID of the user to initiate KYC for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["data", "provider"])
    async def create(
        self,
        user_id: str,
        *,
        data: kyc_create_params.Variant0Data,
        provider: Literal["bridge"] | Literal["bridge-sandbox"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCCreateResponse:
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return await self._post(
            f"/v1/users/{user_id}/fiat/kyc",
            body=await async_maybe_transform(
                {
                    "data": data,
                    "provider": provider,
                },
                kyc_create_params.KYCCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KYCCreateResponse,
        )

    @overload
    async def update(
        self,
        user_id: str,
        *,
        data: kyc_update_params.Variant0Data,
        provider: Literal["bridge"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCUpdateResponse:
        """
        Update the KYC verification status for a user from the configured provider

        Args:
          user_id: The ID of the user to update KYC status for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        user_id: str,
        *,
        data: kyc_update_params.Variant1Data,
        provider: Literal["bridge-sandbox"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCUpdateResponse:
        """
        Update the KYC verification status for a user from the configured provider

        Args:
          user_id: The ID of the user to update KYC status for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["data", "provider"])
    async def update(
        self,
        user_id: str,
        *,
        data: kyc_update_params.Variant0Data,
        provider: Literal["bridge"] | Literal["bridge-sandbox"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCUpdateResponse:
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return await self._patch(
            f"/v1/users/{user_id}/fiat/kyc",
            body=await async_maybe_transform(
                {
                    "data": data,
                    "provider": provider,
                },
                kyc_update_params.KYCUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KYCUpdateResponse,
        )

    async def get(
        self,
        user_id: str,
        *,
        provider: Literal["bridge", "bridge-sandbox"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KYCGetResponse:
        """
        Get the current KYC verification status for a user from the configured provider

        Args:
          user_id: The ID of the user to get KYC status for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return await self._get(
            f"/v1/users/{user_id}/fiat/kyc",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"provider": provider}, kyc_get_params.KYCGetParams),
            ),
            cast_to=KYCGetResponse,
        )


class KYCResourceWithRawResponse:
    def __init__(self, kyc: KYCResource) -> None:
        self._kyc = kyc

        self.create = to_raw_response_wrapper(
            kyc.create,
        )
        self.update = to_raw_response_wrapper(
            kyc.update,
        )
        self.get = to_raw_response_wrapper(
            kyc.get,
        )


class AsyncKYCResourceWithRawResponse:
    def __init__(self, kyc: AsyncKYCResource) -> None:
        self._kyc = kyc

        self.create = async_to_raw_response_wrapper(
            kyc.create,
        )
        self.update = async_to_raw_response_wrapper(
            kyc.update,
        )
        self.get = async_to_raw_response_wrapper(
            kyc.get,
        )


class KYCResourceWithStreamingResponse:
    def __init__(self, kyc: KYCResource) -> None:
        self._kyc = kyc

        self.create = to_streamed_response_wrapper(
            kyc.create,
        )
        self.update = to_streamed_response_wrapper(
            kyc.update,
        )
        self.get = to_streamed_response_wrapper(
            kyc.get,
        )


class AsyncKYCResourceWithStreamingResponse:
    def __init__(self, kyc: AsyncKYCResource) -> None:
        self._kyc = kyc

        self.create = async_to_streamed_response_wrapper(
            kyc.create,
        )
        self.update = async_to_streamed_response_wrapper(
            kyc.update,
        )
        self.get = async_to_streamed_response_wrapper(
            kyc.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["OnrampCreateResponse", "DepositInstructions"]


class DepositInstructions(BaseModel):
    amount: str

    currency: Literal["usd", "eur"]

    payment_rail: Literal["sepa", "ach_push", "wire"]

    account_holder_name: Optional[str] = None

    bank_account_number: Optional[str] = None

    bank_address: Optional[str] = None

    bank_beneficiary_name: Optional[str] = None

    bank_name: Optional[str] = None

    bank_routing_number: Optional[str] = None

    bic: Optional[str] = None

    deposit_message: Optional[str] = None

    iban: Optional[str] = None


class OnrampCreateResponse(BaseModel):
    id: str

    deposit_instructions: DepositInstructions

    status: Literal[
        "awaiting_funds",
        "in_review",
        "funds_received",
        "payment_submitted",
        "payment_processed",
        "canceled",
        "error",
        "undeliverable",
        "returned",
        "refunded",
    ]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .fiat import (
    FiatResource,
    AsyncFiatResource,
    FiatResourceWithRawResponse,
    AsyncFiatResourceWithRawResponse,
    FiatResourceWithStreamingResponse,
    AsyncFiatResourceWithStreamingResponse,
)
from .users import (
    UsersResource,
    AsyncUsersResource,
    UsersResourceWithRawResponse,
    AsyncUsersResourceWithRawResponse,
    UsersResourceWithStreamingResponse,
    AsyncUsersResourceWithStreamingResponse,
)
from .wallets import (
    WalletsResource,
    AsyncWalletsResource,
    WalletsResourceWithRawResponse,
    AsyncWalletsResourceWithRawResponse,
    WalletsResourceWithStreamingResponse,
    AsyncWalletsResourceWithStreamingResponse,
)
from .policies import (
    PoliciesResource,
    AsyncPoliciesResource,
    PoliciesResourceWithRawResponse,
    AsyncPoliciesResourceWithRawResponse,
    PoliciesResourceWithStreamingResponse,
    AsyncPoliciesResourceWithStreamingResponse,
)
from .key_quorums import (
    KeyQuorumsResource,
    AsyncKeyQuorumsResource,
    KeyQuorumsResourceWithRawResponse,
    AsyncKeyQuorumsResourceWithRawResponse,
    KeyQuorumsResourceWithStreamingResponse,
    AsyncKeyQuorumsResourceWithStreamingResponse,
)
from .transactions import (
    TransactionsResource,
    AsyncTransactionsResource,
    TransactionsResourceWithRawResponse,
    AsyncTransactionsResourceWithRawResponse,
    TransactionsResourceWithStreamingResponse,
    AsyncTransactionsResourceWithStreamingResponse,
)

__all__ = [
    "WalletsResource",
    "AsyncWalletsResource",
    "WalletsResourceWithRawResponse",
    "AsyncWalletsResourceWithRawResponse",
    "WalletsResourceWithStreamingResponse",
    "AsyncWalletsResourceWithStreamingResponse",
    "UsersResource",
    "AsyncUsersResource",
    "UsersResourceWithRawResponse",
    "AsyncUsersResourceWithRawResponse",
    "UsersResourceWithStreamingResponse",
    "AsyncUsersResourceWithStreamingResponse",
    "PoliciesResource",
    "AsyncPoliciesResource",
    "PoliciesResourceWithRawResponse",
    "AsyncPoliciesResourceWithRawResponse",
    "PoliciesResourceWithStreamingResponse",
    "AsyncPoliciesResourceWithStreamingResponse",
    "TransactionsResource",
    "AsyncTransactionsResource",
    "TransactionsResourceWithRawResponse",
    "AsyncTransactionsResourceWithRawResponse",
    "TransactionsResourceWithStreamingResponse",
    "AsyncTransactionsResourceWithStreamingResponse",
    "KeyQuorumsResource",
    "AsyncKeyQuorumsResource",
    "KeyQuorumsResourceWithRawResponse",
    "AsyncKeyQuorumsResourceWithRawResponse",
    "KeyQuorumsResourceWithStreamingResponse",
    "AsyncKeyQuorumsResourceWithStreamingResponse",
    "FiatResource",
    "AsyncFiatResource",
    "FiatResourceWithRawResponse",
    "AsyncFiatResourceWithRawResponse",
    "FiatResourceWithStreamingResponse",
    "AsyncFiatResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from typing_extensions import Literal, TypeAlias

from .._models import BaseModel

__all__ = [
    "Policy",
    "Rule",
    "RuleCondition",
    "RuleConditionEthereumTransaction",
    "RuleConditionEthereumCalldata",
    "RuleConditionEthereumTypedDataDomain",
    "RuleConditionEthereumTypedDataMessage",
    "RuleConditionEthereumTypedDataMessageTypedData",
    "RuleConditionEthereumTypedDataMessageTypedDataType",
    "RuleConditionSolanaProgramInstruction",
    "RuleConditionSolanaSystemProgramInstruction",
    "RuleConditionSolanaTokenProgramInstruction",
]


class RuleConditionEthereumTransaction(BaseModel):
    field: Literal["to", "value"]

    field_source: Literal["ethereum_transaction"]

    operator: Literal["eq", "gt", "gte", "lt", "lte", "in"]

    value: Union[str, List[str]]


class RuleConditionEthereumCalldata(BaseModel):
    abi: object

    field: str

    field_source: Literal["ethereum_calldata"]

    operator: Literal["eq", "gt", "gte", "lt", "lte", "in"]

    value: Union[str, List[str]]


class RuleConditionEthereumTypedDataDomain(BaseModel):
    field: Literal["chainId", "verifyingContract"]

    field_source: Literal["ethereum_typed_data_domain"]

    operator: Literal["eq", "gt", "gte", "lt", "lte", "in"]

    value: Union[str, List[str]]


class RuleConditionEthereumTypedDataMessageTypedDataType(BaseModel):
    name: str

    type: str


class RuleConditionEthereumTypedDataMessageTypedData(BaseModel):
    primary_type: str

    types: Dict[str, List[RuleConditionEthereumTypedDataMessageTypedDataType]]


class RuleConditionEthereumTypedDataMessage(BaseModel):
    field: str

    field_source: Literal["ethereum_typed_data_message"]

    operator: Literal["eq", "gt", "gte", "lt", "lte", "in"]

    typed_data: RuleConditionEthereumTypedDataMessageTypedData

    value: Union[str, List[str]]


class RuleConditionSolanaProgramInstruction(BaseModel):
    field: Literal["programId"]

    field_source: Literal["solana_program_instruction"]

    operator: Literal["eq", "gt", "gte", "lt", "lte", "in"]

    value: Union[str, List[str]]


class RuleConditionSolanaSystemProgramInstruction(BaseModel):
    field: Literal["instructionName", "Transfer.from", "Transfer.to", "Transfer.lamports"]

    field_source: Literal["solana_system_program_instruction"]

    operator: Literal["eq", "gt", "gte", "lt", "lte", "in"]

    value: Union[str, List[str]]


class RuleConditionSolanaTokenProgramInstruction(BaseModel):
    field: Literal[
        "instructionName",
        "TransferChecked.source",
        "TransferChecked.destination",
        "TransferChecked.authority",
        "TransferChecked.amount",
        "TransferChecked.mint",
    ]

    field_source: Literal["solana_token_program_instruction"]

    operator: Literal["eq", "gt", "gte", "lt", "lte", "in"]

    value: Union[str, List[str]]


RuleCondition: TypeAlias = Union[
    RuleConditionEthereumTransaction,
    RuleConditionEthereumCalldata,
    RuleConditionEthereumTypedDataDomain,
    RuleConditionEthereumTypedDataMessage,
    RuleConditionSolanaProgramInstruction,
    RuleConditionSolanaSystemProgramInstruction,
    RuleConditionSolanaTokenProgramInstruction,
]


class Rule(BaseModel):
    action: Literal["ALLOW", "DENY"]
    """Action to take if the conditions are true."""

    conditions: List[RuleCondition]
    """
    An unordered set of boolean conditions that define the action the rule allows or
    denies.
    """

    method: Literal[
        "eth_sendTransaction",
        "eth_signTransaction",
        "eth_signTypedData_v4",
        "signTransaction",
        "signAndSendTransaction",
        "exportPrivateKey",
        "*",
    ]
    """Method the rule applies to."""

    name: str
    """Name to assign to rule."""


class Policy(BaseModel):
    id: str
    """Unique ID of the created policy.

    This will be the primary identifier when using the policy in the future.
    """

    chain_type: Literal["ethereum"]
    """Chain type the policy applies to."""

    created_at: float
    """Unix timestamp of when the policy was created in milliseconds."""

    name: str
    """Name to assign to policy."""

    owner_id: Optional[str] = None
    """The key quorum ID of the owner of the policy."""

    rules: List[Rule]
    """The rules that apply to each method the policy covers."""

    version: Literal["1.0"]
    """Version of the policy. Currently, 1.0 is the only version."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .kyc import (
    KYCResource,
    AsyncKYCResource,
    KYCResourceWithRawResponse,
    AsyncKYCResourceWithRawResponse,
    KYCResourceWithStreamingResponse,
    AsyncKYCResourceWithStreamingResponse,
)
from .onramp import (
    OnrampResource,
    AsyncOnrampResource,
    OnrampResourceWithRawResponse,
    AsyncOnrampResourceWithRawResponse,
    OnrampResourceWithStreamingResponse,
    AsyncOnrampResourceWithStreamingResponse,
)
from .offramp import (
    OfframpResource,
    AsyncOfframpResource,
    OfframpResourceWithRawResponse,
    AsyncOfframpResourceWithRawResponse,
    OfframpResourceWithStreamingResponse,
    AsyncOfframpResourceWithStreamingResponse,
)
from .accounts import (
    AccountsResource,
    AsyncAccountsResource,
    AccountsResourceWithRawResponse,
    AsyncAccountsResourceWithRawResponse,
    AccountsResourceWithStreamingResponse,
    AsyncAccountsResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["FiatResource", "AsyncFiatResource"]


class FiatResource(SyncAPIResource):
    @cached_property
    def accounts(self) -> AccountsResource:
        return AccountsResource(self._client)

    @cached_property
    def kyc(self) -> KYCResource:
        return KYCResource(self._client)

    @cached_property
    def onramp(self) -> OnrampResource:
        return OnrampResource(self._client)

    @cached_property
    def offramp(self) -> OfframpResource:
        return OfframpResource(self._client)

    @cached_property
    def with_raw_response(self) -> FiatResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/privy-io/python-sdk#accessing-raw-response-data-eg-headers
        """
        return FiatResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> FiatResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/privy-io/python-sdk#with_streaming_response
        """
        return FiatResourceWithStreamingResponse(self)


class AsyncFiatResource(AsyncAPIResource):
    @cached_property
    def accounts(self) -> AsyncAccountsResource:
        return AsyncAccountsResource(self._client)

    @cached_property
    def kyc(self) -> AsyncKYCResource:
        return AsyncKYCResource(self._client)

    @cached_property
    def onramp(self) -> AsyncOnrampResource:
        return AsyncOnrampResource(self._client)

    @cached_property
    def offramp(self) -> AsyncOfframpResource:
        return AsyncOfframpResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncFiatResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/privy-io/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncFiatResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncFiatResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/privy-io/python-sdk#with_streaming_response
        """
        return AsyncFiatResourceWithStreamingResponse(self)


class FiatResourceWithRawResponse:
    def __init__(self, fiat: FiatResource) -> None:
        self._fiat = fiat

    @cached_property
    def accounts(self) -> AccountsResourceWithRawResponse:
        return AccountsResourceWithRawResponse(self._fiat.accounts)

    @cached_property
    def kyc(self) -> KYCResourceWithRawResponse:
        return KYCResourceWithRawResponse(self._fiat.kyc)

    @cached_property
    def onramp(self) -> OnrampResourceWithRawResponse:
        return OnrampResourceWithRawResponse(self._fiat.onramp)

    @cached_property
    def offramp(self) -> OfframpResourceWithRawResponse:
        return OfframpResourceWithRawResponse(self._fiat.offramp)


class AsyncFiatResourceWithRawResponse:
    def __init__(self, fiat: AsyncFiatResource) -> None:
        self._fiat = fiat

    @cached_property
    def accounts(self) -> AsyncAccountsResourceWithRawResponse:
        return AsyncAccountsResourceWithRawResponse(self._fiat.accounts)

    @cached_property
    def kyc(self) -> AsyncKYCResourceWithRawResponse:
        return AsyncKYCResourceWithRawResponse(self._fiat.kyc)

    @cached_property
    def onramp(self) -> AsyncOnrampResourceWithRawResponse:
        return AsyncOnrampResourceWithRawResponse(self._fiat.onramp)

    @cached_property
    def offramp(self) -> AsyncOfframpResourceWithRawResponse:
        return AsyncOfframpResourceWithRawResponse(self._fiat.offramp)


class FiatResourceWithStreamingResponse:
    def __init__(self, fiat: FiatResource) -> None:
        self._fiat = fiat

    @cached_property
    def accounts(self) -> AccountsResourceWithStreamingResponse:
        return AccountsResourceWithStreamingResponse(self._fiat.accounts)

    @cached_property
    def kyc(self) -> KYCResourceWithStreamingResponse:
        return KYCResourceWithStreamingResponse(self._fiat.kyc)

    @cached_property
    def onramp(self) -> OnrampResourceWithStreamingResponse:
        return OnrampResourceWithStreamingResponse(self._fiat.onramp)

    @cached_property
    def offramp(self) -> OfframpResourceWithStreamingResponse:
        return OfframpResourceWithStreamingResponse(self._fiat.offramp)


class AsyncFiatResourceWithStreamingResponse:
    def __init__(self, fiat: AsyncFiatResource) -> None:
        self._fiat = fiat

    @cached_property
    def accounts(self) -> AsyncAccountsResourceWithStreamingResponse:
        return AsyncAccountsResourceWithStreamingResponse(self._fiat.accounts)

    @cached_property
    def kyc(self) -> AsyncKYCResourceWithStreamingResponse:
        return AsyncKYCResourceWithStreamingResponse(self._fiat.kyc)

    @cached_property
    def onramp(self) -> AsyncOnrampResourceWithStreamingResponse:
        return AsyncOnrampResourceWithStreamingResponse(self._fiat.onramp)

    @cached_property
    def offramp(self) -> AsyncOfframpResourceWithStreamingResponse:
        return AsyncOfframpResourceWithStreamingResponse(self._fiat.offramp)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["BalanceGetResponse", "Balance"]


class Balance(BaseModel):
    asset: Literal["usdc", "eth"]

    chain: Literal["ethereum", "arbitrum", "base", "linea", "optimism", "zksync_era"]

    display_values: Dict[str, str]

    raw_value: str

    raw_value_decimals: float


class BalanceGetResponse(BaseModel):
    balances: List[Balance]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "User",
    "LinkedAccount",
    "LinkedAccountEmail",
    "LinkedAccountPhone",
    "LinkedAccountCrossApp",
    "LinkedAccountCrossAppEmbeddedWallet",
    "LinkedAccountCrossAppSmartWallet",
    "LinkedAccountAuthorizationKey",
    "LinkedAccountCustomJwt",
    "LinkedAccountApple",
    "LinkedAccountDiscord",
    "LinkedAccountGitHub",
    "LinkedAccountGoogle",
    "LinkedAccountInstagram",
    "LinkedAccountLinkedIn",
    "LinkedAccountSpotify",
    "LinkedAccountTiktok",
    "LinkedAccountTwitter",
    "LinkedAccountSmartWallet",
    "LinkedAccountPasskey",
    "LinkedAccountFarcaster",
    "LinkedAccountEthereum",
    "LinkedAccountEthereumEmbeddedWallet",
    "LinkedAccountSolana",
    "LinkedAccountSolanaEmbeddedWallet",
    "LinkedAccountBitcoinSegwitEmbeddedWallet",
    "LinkedAccountBitcoinTaprootEmbeddedWallet",
    "MfaMethod",
    "MfaMethodPasskey",
    "MfaMethodSMS",
    "MfaMethodTotp",
]


class LinkedAccountEmail(BaseModel):
    address: str

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    type: Literal["email"]

    verified_at: float


class LinkedAccountPhone(BaseModel):
    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    phone_number: str = FieldInfo(alias="phoneNumber")

    type: Literal["phone"]

    verified_at: float


class LinkedAccountCrossAppEmbeddedWallet(BaseModel):
    address: str


class LinkedAccountCrossAppSmartWallet(BaseModel):
    address: str


class LinkedAccountCrossApp(BaseModel):
    embedded_wallets: List[LinkedAccountCrossAppEmbeddedWallet]

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    provider_app_id: str

    smart_wallets: List[LinkedAccountCrossAppSmartWallet]

    subject: str

    type: Literal["cross_app"]

    verified_at: float


class LinkedAccountAuthorizationKey(BaseModel):
    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    public_key: str

    type: Literal["authorization_key"]

    verified_at: float


class LinkedAccountCustomJwt(BaseModel):
    custom_user_id: str

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    type: Literal["custom_auth"]

    verified_at: float


class LinkedAccountApple(BaseModel):
    email: Optional[str] = None

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    subject: str

    type: Literal["apple_oauth"]

    verified_at: float


class LinkedAccountDiscord(BaseModel):
    email: Optional[str] = None

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    subject: str

    type: Literal["discord_oauth"]

    username: Optional[str] = None

    verified_at: float


class LinkedAccountGitHub(BaseModel):
    email: Optional[str] = None

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    name: Optional[str] = None

    subject: str

    type: Literal["github_oauth"]

    username: Optional[str] = None

    verified_at: float


class LinkedAccountGoogle(BaseModel):
    email: str

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    name: Optional[str] = None

    subject: str

    type: Literal["google_oauth"]

    verified_at: float


class LinkedAccountInstagram(BaseModel):
    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    subject: str

    type: Literal["instagram_oauth"]

    username: Optional[str] = None

    verified_at: float


class LinkedAccountLinkedIn(BaseModel):
    email: Optional[str] = None

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    subject: str

    type: Literal["linkedin_oauth"]

    verified_at: float

    name: Optional[str] = None

    vanity_name: Optional[str] = None


class LinkedAccountSpotify(BaseModel):
    email: Optional[str] = None

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    name: Optional[str] = None

    subject: str

    type: Literal["spotify_oauth"]

    verified_at: float


class LinkedAccountTiktok(BaseModel):
    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    name: Optional[str] = None

    subject: str

    type: Literal["tiktok_oauth"]

    username: Optional[str] = None

    verified_at: float


class LinkedAccountTwitter(BaseModel):
    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    name: Optional[str] = None

    profile_picture_url: Optional[str] = None

    subject: str

    type: Literal["twitter_oauth"]

    username: Optional[str] = None

    verified_at: float


class LinkedAccountSmartWallet(BaseModel):
    address: str

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    smart_wallet_type: Literal["safe", "kernel", "biconomy", "light_account", "coinbase_smart_wallet", "thirdweb"]

    type: Literal["smart_wallet"]

    verified_at: float


class LinkedAccountPasskey(BaseModel):
    credential_id: str

    enrolled_in_mfa: bool

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    type: Literal["passkey"]

    verified_at: float

    authenticator_name: Optional[str] = None

    created_with_browser: Optional[str] = None

    created_with_device: Optional[str] = None

    created_with_os: Optional[str] = None


class LinkedAccountFarcaster(BaseModel):
    fid: float

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    owner_address: str

    type: Literal["farcaster"]

    verified_at: float

    bio: Optional[str] = None

    display_name: Optional[str] = None

    homepage_url: Optional[str] = None

    profile_picture: Optional[str] = None

    profile_picture_url: Optional[str] = None

    signer_public_key: Optional[str] = None

    username: Optional[str] = None


class LinkedAccountEthereum(BaseModel):
    address: str

    chain_type: Literal["ethereum"]

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    type: Literal["wallet"]

    verified_at: float

    wallet_client: Literal["unknown"]

    chain_id: Optional[str] = None

    connector_type: Optional[str] = None

    wallet_client_type: Optional[str] = None


class LinkedAccountEthereumEmbeddedWallet(BaseModel):
    id: Optional[str] = None

    address: str

    chain_id: str

    chain_type: Literal["ethereum"]

    connector_type: Literal["embedded"]

    delegated: bool

    first_verified_at: Optional[float] = None

    imported: bool

    latest_verified_at: Optional[float] = None

    recovery_method: Literal["privy", "user-passcode", "google-drive", "icloud", "recovery-encryption-key", "privy-v2"]

    type: Literal["wallet"]

    verified_at: float

    wallet_client: Literal["privy"]

    wallet_client_type: Literal["privy"]

    wallet_index: float


class LinkedAccountSolana(BaseModel):
    address: str

    chain_type: Literal["solana"]

    first_verified_at: Optional[float] = None

    latest_verified_at: Optional[float] = None

    type: Literal["wallet"]

    verified_at: float

    wallet_client: Literal["unknown"]

    connector_type: Optional[str] = None

    wallet_client_type: Optional[str] = None


class LinkedAccountSolanaEmbeddedWallet(BaseModel):
    id: Optional[str] = None

    address: str

    chain_id: str

    chain_type: Literal["solana"]

    connector_type: Literal["embedded"]

    delegated: bool

    first_verified_at: Optional[float] = None

    imported: bool

    latest_verified_at: Optional[float] = None

    public_key: str

    recovery_method: Literal["privy", "user-passcode", "google-drive", "icloud", "recovery-encryption-key", "privy-v2"]

    type: Literal["wallet"]

    verified_at: float

    wallet_client: Literal["privy"]

    wallet_client_type: Literal["privy"]

    wallet_index: float


class LinkedAccountBitcoinSegwitEmbeddedWallet(BaseModel):
    id: Optional[str] = None

    address: str

    chain_id: str

    chain_type: Literal["bitcoin-segwit"]

    connector_type: Literal["embedded"]

    delegated: bool

    first_verified_at: Optional[float] = None

    imported: bool

    latest_verified_at: Optional[float] = None

    public_key: str

    recovery_method: Literal["privy", "user-passcode", "google-drive", "icloud", "recovery-encryption-key", "privy-v2"]

    type: Literal["wallet"]

    verified_at: float

    wallet_client: Literal["privy"]

    wallet_client_type: Literal["privy"]

    wallet_index: float


class LinkedAccountBitcoinTaprootEmbeddedWallet(BaseModel):
    id: Optional[str] = None

    address: str

    chain_id: str

    chain_type: Literal["bitcoin-taproot"]

    connector_type: Literal["embedded"]

    delegated: bool

    first_verified_at: Optional[float] = None

    imported: bool

    latest_verified_at: Optional[float] = None

    public_key: str

    recovery_method: Literal["privy", "user-passcode", "google-drive", "icloud", "recovery-encryption-key", "privy-v2"]

    type: Literal["wallet"]

    verified_at: float

    wallet_client: Literal["privy"]

    wallet_client_type: Literal["privy"]

    wallet_index: float


LinkedAccount: TypeAlias = Union[
    LinkedAccountEmail,
    LinkedAccountPhone,
    LinkedAccountCrossApp,
    LinkedAccountAuthorizationKey,
    LinkedAccountCustomJwt,
    LinkedAccountApple,
    LinkedAccountDiscord,
    LinkedAccountGitHub,
    LinkedAccountGoogle,
    LinkedAccountInstagram,
    LinkedAccountLinkedIn,
    LinkedAccountSpotify,
    LinkedAccountTiktok,
    LinkedAccountTwitter,
    LinkedAccountSmartWallet,
    LinkedAccountPasskey,
    LinkedAccountFarcaster,
    LinkedAccountEthereum,
    LinkedAccountEthereumEmbeddedWallet,
    LinkedAccountSolana,
    LinkedAccountSolanaEmbeddedWallet,
    LinkedAccountBitcoinSegwitEmbeddedWallet,
    LinkedAccountBitcoinTaprootEmbeddedWallet,
]


class MfaMethodPasskey(BaseModel):
    type: Literal["passkey"]

    verified_at: float


class MfaMethodSMS(BaseModel):
    type: Literal["sms"]

    verified_at: float


class MfaMethodTotp(BaseModel):
    type: Literal["totp"]

    verified_at: float


MfaMethod: TypeAlias = Union[MfaMethodPasskey, MfaMethodSMS, MfaMethodTotp]


class User(BaseModel):
    id: str

    created_at: float
    """Unix timestamp of when the user was created in milliseconds."""

    has_accepted_terms: bool
    """Indicates if the user has accepted the terms of service."""

    is_guest: bool
    """Indicates if the user is a guest account user."""

    linked_accounts: List[LinkedAccount]

    mfa_methods: List[MfaMethod]

    custom_metadata: Optional[Dict[str, Union[str, float, bool]]] = None
    """Custom metadata associated with the user."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Optional
from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.wallets import transaction_get_params
from ...types.wallets.transaction_get_response import TransactionGetResponse

__all__ = ["TransactionsResource", "AsyncTransactionsResource"]


class TransactionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TransactionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/privy-io/python-sdk#accessing-raw-response-data-eg-headers
        """
        return TransactionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TransactionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/privy-io/python-sdk#with_streaming_response
        """
        return TransactionsResourceWithStreamingResponse(self)

    def get(
        self,
        path_wallet_id: str,
        *,
        asset: Union[Literal["usdc", "eth"], List[Literal["usdc", "eth"]]],
        chain: Literal["base"],
        query_wallet_id: str,
        cursor: str | NotGiven = NOT_GIVEN,
        limit: Optional[float] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TransactionGetResponse:
        """
        Get incoming and outgoing transactions of a wallet by wallet ID.

        Args:
          path_wallet_id: ID of the wallet.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_wallet_id:
            raise ValueError(f"Expected a non-empty value for `path_wallet_id` but received {path_wallet_id!r}")
        return self._get(
            f"/v1/wallets/{path_wallet_id}/transactions",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "asset": asset,
                        "chain": chain,
                        "query_wallet_id": query_wallet_id,
                        "cursor": cursor,
                        "limit": limit,
                    },
                    transaction_get_params.TransactionGetParams,
                ),
            ),
            cast_to=TransactionGetResponse,
        )


class AsyncTransactionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTransactionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/privy-io/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncTransactionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTransactionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/privy-io/python-sdk#with_streaming_response
        """
        return AsyncTransactionsResourceWithStreamingResponse(self)

    async def get(
        self,
        path_wallet_id: str,
        *,
        asset: Union[Literal["usdc", "eth"], List[Literal["usdc", "eth"]]],
        chain: Literal["base"],
        query_wallet_id: str,
        cursor: str | NotGiven = NOT_GIVEN,
        limit: Optional[float] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TransactionGetResponse:
        """
        Get incoming and outgoing transactions of a wallet by wallet ID.

        Args:
          path_wallet_id: ID of the wallet.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_wallet_id:
            raise ValueError(f"Expected a non-empty value for `path_wallet_id` but received {path_wallet_id!r}")
        return await self._get(
            f"/v1/wallets/{path_wallet_id}/transactions",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "asset": asset,
                        "chain": chain,
                        "query_wallet_id": query_wallet_id,
                        "cursor": cursor,
                        "limit": limit,
                    },
                    transaction_get_params.TransactionGetParams,
                ),
            ),
            cast_to=TransactionGetResponse,
        )


class TransactionsResourceWithRawResponse:
    def __init__(self, transactions: TransactionsResource) -> None:
        self._transactions = transactions

        self.get = to_raw_response_wrapper(
            transactions.get,
        )


class AsyncTransactionsResourceWithRawResponse:
    def __init__(self, transactions: AsyncTransactionsResource) -> None:
        self._transactions = transactions

        self.get = async_to_raw_response_wrapper(
            transactions.get,
        )


class TransactionsResourceWithStreamingResponse:
    def __init__(self, transactions: TransactionsResource) -> None:
        self._transactions = transactions

        self.get = to_streamed_response_wrapper(
            transactions.get,
        )


class AsyncTransactionsResourceWithStreamingResponse:
    def __init__(self, transactions: AsyncTransactionsResource) -> None:
        self._transactions = transactions

        self.get = async_to_streamed_response_wrapper(
            transactions.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["KeyQuorum", "AuthorizationKey"]


class AuthorizationKey(BaseModel):
    display_name: Optional[str] = None

    public_key: str


class KeyQuorum(BaseModel):
    id: str

    authorization_keys: List[AuthorizationKey]

    authorization_threshold: Optional[float] = None

    display_name: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from typing_extensions import Literal, Required, TypeAlias, TypedDict

__all__ = [
    "WalletCreateWalletsWithRecoveryParams",
    "PrimarySigner",
    "RecoveryUser",
    "RecoveryUserLinkedAccount",
    "RecoveryUserLinkedAccountUnionMember0",
    "RecoveryUserLinkedAccountUnionMember1",
    "Wallet",
]


class WalletCreateWalletsWithRecoveryParams(TypedDict, total=False):
    primary_signer: Required[PrimarySigner]

    recovery_user: Required[RecoveryUser]

    wallets: Required[Iterable[Wallet]]


class PrimarySigner(TypedDict, total=False):
    subject_id: Required[str]
    """The JWT subject ID of the user."""


class RecoveryUserLinkedAccountUnionMember0(TypedDict, total=False):
    address: Required[str]
    """The email address of the user."""

    type: Required[Literal["email"]]


class RecoveryUserLinkedAccountUnionMember1(TypedDict, total=False):
    custom_user_id: Required[str]
    """The JWT subject ID of the user."""

    type: Required[Literal["custom_auth"]]


RecoveryUserLinkedAccount: TypeAlias = Union[
    RecoveryUserLinkedAccountUnionMember0, RecoveryUserLinkedAccountUnionMember1
]


class RecoveryUser(TypedDict, total=False):
    linked_accounts: Required[Iterable[RecoveryUserLinkedAccount]]


class Wallet(TypedDict, total=False):
    chain_type: Required[Literal["solana", "ethereum", "cosmos", "stellar", "sui"]]
    """Chain type of the wallet. "ethereum" supports any EVM-compatible network."""

    policy_ids: List[str]
    """List of policy IDs for policies that should be enforced on the wallet.

    Currently, only one policy is supported per wallet.
    """
